# Potato Distillery 🥔 ➡  🥃

The purpose of this package is to make easier for users
to create smaller versions of popular ML models, in order
to fine-tune distilled versions of them.

Requirements:
* Huggingface 🤗
* Transformers 🤖
* Pytorch 🔥

Current support:
* BERT (Pytorch)
* GPT-2 (Pytorch)
* GPT-Neo (Pytorch)



